==> haskell-hashable-1.2.6.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hashable
version: 1.2.6.1
id: hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
key: hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
license: BSD3
maintainer: johan.tibell@gmail.com
stability: Provisional
homepage: http://github.com/tibbe/hashable
synopsis: A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.
category: Data
author: Milan Straka <fox@ucw.cz>
        Johan Tibell <johan.tibell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Hashable Data.Hashable.Lifted
hidden-modules: Data.Hashable.Class Data.Hashable.Generic
abi: 6e4b4a70e10d525b7db51e3859aab169
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hashable-1.2.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hashable-1.2.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hashable-1.2.6.1
hs-libraries: HShashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
depends:
    base-4.10.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0 ghc-prim-0.5.1.1
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj integer-gmp-1.0.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             integer-gmp-1.0.1.0=7d948c9c98bb9ecc021f32964406f9ad
haddock-interfaces: /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html: /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-1.2.6.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hashable
version: 1.2.6.1
id: hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
key: hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
license: BSD3
maintainer: johan.tibell@gmail.com
stability: Provisional
homepage: http://github.com/tibbe/hashable
synopsis: A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.
category: Data
author: Milan Straka <fox@ucw.cz>
        Johan Tibell <johan.tibell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Hashable Data.Hashable.Lifted
hidden-modules: Data.Hashable.Class Data.Hashable.Generic
abi: e2c3f4e35e60b5547d3e7a8c501ca6de
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hashable-1.2.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hashable-1.2.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hashable-1.2.6.1
hs-libraries: HShashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
depends:
    base-4.10.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0 ghc-prim-0.5.1.1
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj integer-gmp-1.0.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             integer-gmp-1.0.1.0=7d948c9c98bb9ecc021f32964406f9ad
haddock-interfaces: /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html: /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
